@@ -135,6 +135,7 @@ ARB_REQUIRED_FIELDS = ('tran_key',
 ARB_ALLOWED_FIELDS  = ('tran_key',
                        'login',
                        'id',
+                       'ref_id',
                        'schedule',
                        'amount',
                        'card',
@@ -339,12 +340,8 @@ class RecurringTransaction(Adapter):
         # Coerce to string
         self.subscription_id = str(configuration.pop('id')) if 'id' in configuration else None
         
-        # Create a unique token for the reference ID
-        uid   = uuid.uuid4().hex
-        token = hashlib.sha512(uid).hexdigest()[:20]
-
         # Assign basic configuration points
-        self.ref_id         = token
+        self.ref_id = configuration['ref_id'] if 'ref_id' in configuration else ''
         
         # Standard object attributes
         self.schedule   = None
@@ -367,7 +364,7 @@ class RecurringTransaction(Adapter):
             if 'unit' in schedule:
                 self.schedule['unit'] = schedule['unit']
                 
-                if unit not in ('months', 'days'):
+                if self.schedule['unit'] not in ('months', 'days'):
                     raise ARBException('The interval unit "%s" is not supported' % unit)
             else:
                 self.schedule['unit'] = 'months'
@@ -375,7 +372,7 @@ class RecurringTransaction(Adapter):
             if 'cycles' in schedule:
                 self.schedule['cycles'] = schedule['cycles']
                 
-                if int(cycles) > 9999:
+                if int(self.schedule['cycles']) > 9999:
                     raise ARBException('The subscription cycle cannot exceed 9999 (ongoing)')
             else:
                 self.schedule['cycles'] = 9999
